| Score | Dummy (prior) | Explanation
--- | --- | --- | ---
AUC | 0.779361 | 0.500000 | Area under the ROC curve (true pos. rate vs false pos. rate); ranges from 0.5 (purely random classifier) to 1.0 (perfect classifier)
True Positive Rate | 0.338983 | 0.000000 | 33.9% of positive instances were correctly identified.; i.e. 20 "Defaulted" labels were correctly identified out of 59 instances; a.k.a Sensitivity/Recall
True Negative Rate | 0.936170 | 1.000000 | 93.6% of negative instances were correctly identified.; i.e. 132 "Not Defaulted" labels were correctly identified out of 141 instances
False Positive Rate | 0.063830 | 0.000000 | 6.4% of negative instances were incorrectly identified as positive; i.e. 9 "Not Defaulted" labels were incorrectly identified as "Defaulted", out of 141 instances
False Negative Rate | 0.661017 | 1.000000 | 66.1% of positive instances were incorrectly identified as negative; i.e. 39 "Defaulted" labels were incorrectly identified as "Not Defaulted", out of 59 instances
Positive Predictive Value | 0.689655 | 0.000000 | When the model claims an instance is positive, it is correct 69.0% of the time; i.e. out of the 29 times the model predicted "Defaulted", it was correct 20 times; a.k.a precision
Negative Predictive Value | 0.771930 | 0.705000 | When the model claims an instance is negative, it is correct 77.2% of the time; i.e. out of the 171 times the model predicted "Not Defaulted", it was correct 132 times
F1 Score | 0.454545 | 0.000000 | The F1 score can be interpreted as a weighted average of the precision and recall, where an F1 score reaches its best value at 1 and worst score at 0.
Precision/Recall AUC | 0.588795 | 0.295000 | Precision/Recall AUC is calculated with `average_precision` which summarizes a precision-recall curve as the weighted mean of precisions achieved at each threshold. See sci-kit learn documentation for caveats.
Accuracy | 0.760000 | 0.705000 | 76.0% of instances were correctly identified
Error Rate | 0.240000 | 0.295000 | 24.0% of instances were incorrectly identified
% Positive | 0.295000 | 0.295000 | 29.5% of the data are positive; i.e. out of 200 total observations; 59 are labeled as "Defaulted"
Total Observations | 200 | 200 | There are 200 total observations; i.e. sample size